Struct Thread
#[non_exhaustive]pub struct Thread {
pub event_id: OwnedEventId,
pub in_reply_to: Option<InReplyTo>,
pub is_falling_back: bool,
}Expand description
The content of a thread relation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_id: OwnedEventIdThe ID of the root message in the thread.
in_reply_to: Option<InReplyTo>A reply relation.
If this event is a reply and belongs to a thread, this points to the message that is being
replied to, and is_falling_back must be set to false.
If this event is not a reply, this is used as a fallback mechanism for clients that do not
support threads. This should point to the latest message-like event in the thread and
is_falling_back must be set to true.
is_falling_back: boolWhether the m.in_reply_to field is a fallback for older clients or a genuine reply in a
thread.
Implementations
impl Thread
impl Thread
pub fn plain(event_id: OwnedEventId, latest_event_id: OwnedEventId) -> Thread
pub fn plain(event_id: OwnedEventId, latest_event_id: OwnedEventId) -> Thread
Convenience method to create a regular Thread relation with the given root event ID and
latest message-like event ID.
pub fn without_fallback(event_id: OwnedEventId) -> Thread
pub fn without_fallback(event_id: OwnedEventId) -> Thread
Convenience method to create a regular Thread relation with the given root event ID and
without the recommended reply fallback.
pub fn reply(event_id: OwnedEventId, reply_to_event_id: OwnedEventId) -> Thread
pub fn reply(event_id: OwnedEventId, reply_to_event_id: OwnedEventId) -> Thread
Convenience method to create a reply Thread relation with the given root event ID and
replied-to event ID.